<?php

namespace Ecommerce\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\Libs\Util\ReportDecorator;
use Zeedhi\Framework\DataSource\DataSet;

class Lib04500 extends \Zeedhi\Framework\Controller\Report
{

    protected $reportService;
    protected $autorizacaoFornecimentoController;
    protected $entityManager;
    protected $environment;
    protected $birtStrategy;
    
    public function __construct($reportService, $autorizacaoFornecimentoController, $entityManager, $environment, $birtStrategy)
    {
        $this->reportService                     = $reportService;
        $this->autorizacaoFornecimentoController = $autorizacaoFornecimentoController;
        $this->entityManager                     = $entityManager;
        $this->environment                       = $environment;
        $this->birtStrategy                      = $birtStrategy;
    }
    
    /** @var array */
    protected $reportMapping = array(
        
        'LIB04500' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'TIPO'            => 'P_TIPO',
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN',
                        'CDFILDEST'       => 'P_CDFILDEST',
                        'NRAUTOFORN'      => 'P_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'P_NRSEQAPURAF',
                        'NRORG'           => 'P_NRORG',
                        'IDSISDOS'        => 'P_IDSISDOS'
                    )
            ),
        'LIB04501' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'TIPO'            => 'P_TIPO',
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN',
                        'CDFILDEST'       => 'P_CDFILDEST',
                        'NRAUTOFORN'      => 'P_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'P_NRSEQAPURAF',
                        'NRORG'           => 'P_NRORG',
                        'IDSISDOS'        => 'P_IDSISDOS',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                    )
            ),
        'LIB04502' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'CDFILDEST'       => 'L_CDFILDEST',
                        'NRAUTOFORN'      => 'L_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'L_NRSEQAPURAF',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN',
                        'NRLOGPLANITEMAF' => 'P_NRLOGPLANITEMAF',
                        'CDPICTPROD'      => 'P_CDPICTPROD', 
                        'NRORG'           => 'NRORG'
                    )
            ),
        'padraoEnvioAF' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                    array (
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'IDEXIBEOBSFIL'  => 'P_IDEXIBEOBSFIL',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'NRORG'
                    ),
            ),
        'padraoEnvioAFGR' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                    array (
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'IDEXIBEOBSFIL'  => 'P_IDEXIBEOBSFIL',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'NRORG',
                    ),
            ),  
        'AFcomDescricaoProd' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                    array (
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'IDEXIBEOBSFIL'  => 'P_IDEXIBEOBSFIL',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'P_NRORG'
                    ),
            ),
        'CMP03900' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'PROXMES'        => 'P_PROXMES',
                        'IDEXIBEOBSFIL'  => 'P_IMPRIMEOBS',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'P_NRORG'
                    )
            ),
        'CMP03901' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'PROXMES'        => 'P_PROXMES',
                        'IDEXIBEOBSFIL'  => 'P_IMPRIMEOBS',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'P_NRORG'
                    )
            ),
        'CMP03902' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'PROXMES'        => 'P_PROXMES',
                        'IDEXIBEOBSFIL'  => 'P_IMPRIMEOBS',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'P_NRORG'
                    )
            ),
        'CMP03903' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'PROXMES'        => 'P_PROXMES',
                        'IDEXIBEOBSFIL'  => 'P_IMPRIMEOBS',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        'NRORG'          => 'P_NRORG'
                    )
            ),
        '1522/CMP03910' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'PROXMES'        => 'P_PROXMES',
                        'IDEXIBEOBSFIL'  => 'P_IMPRIMEOBS',
                        'NRORG'          => 'P_NRORG'
                        
                    )
            ),
        '1019/CMP03910' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'PROXMES'        => 'P_PROXMES',
                        'IDEXIBEOBSFIL'  => 'P_IMPRIMEOBS',
                        'NRORG'          => 'P_NRORG'
                        
                    )
            )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)    {
        $row = $request->getRow();
        $row['NRORG'] = $this->environment->getNrorgTrab();
        $row['__report_name'] = str_replace('.BIRT', '', $row['__report_name']);
    }
    
    public function afterProcessReport(DTO\Request\Row $request, DTO\Response $response, $report)
    {
        $row = $request->getRow();
        try {
            $this->entityManager->beginTransaction();
            
            $this->autorizacaoFornecimentoController->processaAfsBaixadas($row);
            
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
        
    } 
    
    public function getReportData(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrog = $this->getNrorg();
        if($nrog != null) {
            $this->environment->setNrOrgTrab($nrog);    
        }
        $reportDecoratorController = new ReportDecorator($this->environment);
        $reportData = $reportDecoratorController->getData($request, $response);
    }
    
    public function getNrorg() {
        $nrorg = null;
        $fileDir = \Teknisa\Libs\Util\Utilities::getProductBasePath() . '/modules/login/backend/config/oAccCustom.tek';
        if (file_exists($fileDir)) {
            $fileContents  = file_get_contents($fileDir);
            $fileDecrypted = \Teknisa\Libs\Util\Utilities::zeedhiDecrypt($fileContents, \Teknisa\Libs\Util\Utilities::LOGIN_CRYPT_STRING);
            $fileDecoded   = @json_decode($fileDecrypted, true);
            if(isset($fileDecoded['organizationId']) && is_numeric($fileDecoded['organizationId'])) {
                $nrorg = $fileDecoded['organizationId'];
            }
        }            
        return $nrorg;
    }
}